@@ -90,6 +90,9 @@
 #' as.character(inset). Non-case sensitive partial matching is used, with "é"
 #' interpreted as "e".
 #' 
+#' - **montpellier**: scope perimeter is located within Montpellier. Only
+#'      useful when scope is less than Montpellier (for districts of
+#'      Montpellier).
 #' - **so-ii**: scope perimeter is located within so-ii. Only
 #'      useful when scope is less than so-ii.
 #' - **department**: scope perimeter is located within Hérault
@@ -111,11 +114,19 @@
 #' - **so.ii**: the whole perimiter of so.ii is chosen. This is
 #'      default value.
 #' - **vector of INSEE codes of collectivities in so.ii**: a
-#'      perimeter is build with those collectivies. Only valid codes are taken
+#'      perimeter is built with those collectivies. Only valid codes are taken
 #'      into account. If none is chosen, a warning is dropped, and default
-#'      value is used.
+#'      value is used. See `so.ii::so_ii_collectivity` to have all the available
+#'      collectivities 
+#' - **vector of district for Montpellier**: a perimeter is built with those
+#'      districts. There's 31 district, the selection is made with a character
+#'      vector of the form "montpellier-xx", with "xx" being the number of the
+#'      district ("01", ... "31"). See `so.ii::so_ii_montpellier` to have all
+#'      the available districts.
+#' 
+#' It is not possible to mix collectivities and districts of Montpellier.
 #'
-#' path specification
+#' ## path specification
 #' 
 #' Depending on the extension a device is chosen.
 #' 
@@ -126,7 +137,6 @@
 #' 
 #' If path is NULL, standard plotting is used. If an extension is not managed,
 #' an error is raised.
-
 #'
 #' @param dataset sf object (or list of sf objects...), data to be plotted.
 #'  See details.
@@ -257,22 +267,19 @@ map_so_ii = function(
     }
 
     ## Check scope
+    scope_commune = so.ii::so_ii_collectivity[["commune"]]
+    scope_montpellier = sprintf("montpellier-%s", so.ii::so_ii_montpellier[["district"]])
     if (identical(scope, "so.ii")) {
         scope = so.ii::so_ii_limit
+    } else if (any(scope %in% scope_commune)) {
+        scope = scope[scope %in% scope_commune]
+        scope = suppressMessages(sf::st_union(so.ii::so_ii_collectivity[scope_commune %in% scope, ]))
+    } else if (any(scope %in% scope_montpellier)) {
+        scope = scope[scope %in% scope_montpellier]
+        scope = suppressMessages(sf::st_union(so.ii::so_ii_montpellier[scope_montpellier %in% scope, ]))
     } else {
-        scope = scope[scope %in% so.ii::so_ii_collectivity[["commune"]]]
-        if (length(scope) == 0) {
-            warnings("Nothing pertinent found in scope, default value is used.")
-            scope = so.ii::so_ii_limit
-        } else {
-            scope = suppressMessages(
-                sf::st_union(
-                    so.ii::so_ii_collectivity[
-                        so.ii::so_ii_collectivity[["commune"]] %in% scope,
-                    ]
-                )
-            )
-        }
+        warnings("Nothing pertinent found in scope, default value is used.")
+        scope = so.ii::so_ii_limit
     }
 
     ## Init map
@@ -328,6 +335,7 @@ map_so_ii = function(
     if (!is.null(inset)) {
         inset = gsub("\u00e9", "e", tolower(as.character(inset)[1]))
         admissible = list(
+            "montpellier" = c("34172", "montpellier"),
             "so-ii" = c("so-ii"),
             "department" = c("34", "departement", "department", "herault"),
             "region" = c("76", "occitanie", "region"),
